# py-gdelt

[![CI](https://github.com/RBozydar/py-gdelt/workflows/CI/badge.svg)](https://github.com/RBozydar/py-gdelt/actions/workflows/ci.yml)
[![PyPI version](https://badge.fury.io/py/py-gdelt.svg)](https://badge.fury.io/py/py-gdelt)
[![Python Versions](https://img.shields.io/pypi/pyversions/py-gdelt.svg)](https://pypi.org/project/py-gdelt/)
[![License](https://img.shields.io/github/license/RBozydar/py-gdelt.svg)](https://github.com/RBozydar/py-gdelt/blob/main/LICENSE)
[![Code style: ruff](https://img.shields.io/badge/code%20style-ruff-000000.svg)](https://github.com/astral-sh/ruff)
[![Type checked: mypy](https://img.shields.io/badge/type%20checked-mypy-blue.svg)](http://mypy-lang.org/)
[![Docstring coverage: interrogate](https://img.shields.io/badge/docstrings-100%25-brightgreen.svg)](https://interrogate.readthedocs.io/)

Python library for GDELT - https://www.gdeltproject.org
